/*
 * Traditional system functions for filesystem access.
 *
 * Copyright (C) 2019 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <sys/stat.h>
#include <sys/types.h>

#include <reent.h>            /* struct _reent */

int _close_r(struct _reent *reent, int fd);
int _fstat_r(struct _reent *reent, int fd, struct stat *buf);
int _isatty_r(struct _reent *reent, int fd);
int _link_r(struct _reent *reent, const char *oldpath, const char *newpath);
off_t _lseek_r(struct _reent *reent, int fd, off_t offset, int whence);
int _open_r(struct _reent *reent, const char *name, int flags, int mode);
ssize_t _read_r(struct _reent *reent, int fd, void *buffer, size_t nbytes);
int _rename_r(struct _reent *reent, const char *oldpath, const char *newpath);
int _stat_r(struct _reent *reent, const char *pathname, struct stat *buf);
int _unlink_r(struct _reent *reent, const char *pathname);
ssize_t _write_r(struct _reent *reent, int fd, const void *buffer, size_t nbytes);
